==> blogilo-16.12.3.tar.xz: blogilo-16.12.3/src/composer/webengine/blogilocomposerwebengineview.h <==
/*
  Copyright (c) 2016 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/

#ifndef BLOGILOCOMPOSERWebEngineVIEW_H
#define BLOGILOCOMPOSERWebEngineVIEW_H

#include "composerwebengine.h"
namespace PimCommon
{
class CustomToolsWidgetNg;
}

class BlogiloComposerWebEngineView : public ComposerEditorWebEngine::ComposerWebEngine
{
    Q_OBJECT
public:
    explicit BlogiloComposerWebEngineView(QWidget *parent = Q_NULLPTR);
    ~BlogiloComposerWebEngineView();

    void startEditing();
    void addExtraAction(QMenu *menu) Q_DECL_OVERRIDE;

    void setCustomTools(PimCommon::CustomToolsWidgetNg *customTool);

private Q_SLOTS:
    void slotSendMouseReleaseEvent();

private:
    PimCommon::CustomToolsWidgetNg *mCustomTools;
};

#endif // BLOGILOCOMPOSERWebEngineVIEW_H

==> blogilo-17.04.1.tar.xz: blogilo-17.04.1/src/composer/webengine/blogilocomposerwebengineview.h <==
/*
  Copyright (c) 2016 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/

#ifndef BLOGILOCOMPOSERWebEngineVIEW_H
#define BLOGILOCOMPOSERWebEngineVIEW_H

#include "composerwebengine.h"
namespace PimCommon
{
class CustomToolsWidgetNg;
}

class BlogiloComposerWebEngineView : public ComposerEditorWebEngine::ComposerWebEngine
{
    Q_OBJECT
public:
    explicit BlogiloComposerWebEngineView(QWidget *parent = nullptr);
    ~BlogiloComposerWebEngineView();

    void startEditing();
    void addExtraAction(QMenu *menu) Q_DECL_OVERRIDE;

    void setCustomTools(PimCommon::CustomToolsWidgetNg *customTool);

private Q_SLOTS:
    void slotSendMouseReleaseEvent();

private:
    PimCommon::CustomToolsWidgetNg *mCustomTools;
};

#endif // BLOGILOCOMPOSERWebEngineVIEW_H
